# -*- coding: utf-8 -*-
"""
@author: zsc
@time: 2024/11/18
@desc:  存量运营平台-行为客户行为挖掘及监控
"""
import time
import random
from collections import defaultdict
import matplotlib.pyplot as plt

# 主程序

# main.py
from data.collector  import DataCollector
from data.processor  import DataProcessor
from analyze import BehaviorAnalyzer
from analyze import SegmentUsers
from analyze import DetectAnomalies
from monitor import Monitor
from monitor import GenerateReport

# 主函数
def main():
    # 实例化数据收集模块
    collector = DataCollector.DataCollector()
    raw_data = collector.collect()

    # 实例化数据预处理模块
    preprocessor = DataProcessor.DataPreprocessor(raw_data)
    processed_data = preprocessor.preprocess()

    # 实例化行为分析模块
    analyzer = BehaviorAnalyzer.BehaviorAnalyzer(processed_data)
    behavior_data, action_stats, product_stats, channel_stats  = analyzer.analyze()

    # 实例化用户分群模块
    segmenter = SegmentUsers.UserSegmentation(behavior_data)
    user_segments = segmenter.segment()

    # 实例化异常检测模块
    detector = DetectAnomalies.AnomalyDetector(behavior_data)
    anomalies = detector.detect()

    # 实例化报告生成模块
    generator = GenerateReport.ReportGenerator(processed_data, anomalies, user_segments, action_stats, product_stats, channel_stats)
    report = generator.generate()

    # 打印报告摘要
    print("Report Summary:")
    print(f"Total Users: {report['total_users']}")
    print(f"Total Actions: {report['total_actions']}")
    print(f"Anomalies: {report['anomalies']}")
    print(f"User Segments: {report['user_segments']}")

    # 实例化实时监控模块
    monitor = Monitor.RealTimeMonitor(processed_data)
    print("Starting real-time monitoring...")
    monitor.monitor()

if __name__ == "__main__":
    main()
